@@ -22,6 +22,16 @@
 #ifndef DEBUG_UTILS_H
 #define DEBUG_UTILS_H
 
+#include <QtGlobal>
+
+#if QT_VERSION < 0x050000
+#include <kdebug.h>
+#endif
+
+#if QT_VERSION >= 0x050000
+#include <QLoggingCategory>
+Q_DECLARE_LOGGING_CATEGORY(UMBRELLO)
+#endif
 #include <QMetaEnum>
 #include <QTreeWidget>
 
@@ -77,9 +87,11 @@ public:
 
 protected:
     void update(const QString &name);
+    void updateParentItemCheckBox(QTreeWidgetItem *parent);
     virtual void showEvent(QShowEvent*);
 
 private slots:
+    void slotParentItemClicked(QTreeWidgetItem *parent);
     void slotItemClicked(QTreeWidgetItem* item, int column);
 
 private:
@@ -99,17 +111,21 @@ private:
     explicit Tracer(QWidget *parent = 0);
 };
 
-#include <kdebug.h>
-
 // convenience macros for console output to the Umbrello area
+#if QT_VERSION >= 0x050000
+#define uDebug()   qCDebug(UMBRELLO)
+#define uError()   qCCritical(UMBRELLO)
+#define uWarning() qCWarning(UMBRELLO)
+#else
 #define uDebug()   kDebug(8060)
 #define uError()   kError(8060)
 #define uWarning() kWarning(8060)
+#endif
 
 #define DBG_SRC  QString::fromLatin1(metaObject()->className())
 #define DEBUG_SHOW_FILTER() Tracer::instance()->show()
 #define DEBUG(src)  if (Tracer::instance()->isEnabled(src)) uDebug()
-#define IS_DEBUG_ENABLED(src) Tracer::instance()->isEnabled(src)
+#define IS_DEBUG_ENABLED(src) Tracer::instance()->isEnabled(QString::fromLatin1(#src))
 #define DEBUG_REGISTER(src) class src##Tracer { public: src##Tracer() { Tracer::registerClass(QString::fromLatin1(#src), true, QLatin1String(__FILE__)); } }; static src##Tracer src##TracerGlobal;
 #define DEBUG_REGISTER_DISABLED(src) class src##Tracer { public: src##Tracer() { Tracer::registerClass(QString::fromLatin1(#src), false, QLatin1String(__FILE__)); } }; static src##Tracer src##TracerGlobal;
 
